@@ -1,7 +1,7 @@
 #
 #  dist2dpath.R
 #
-#   $Revision: 1.7 $    $Date: 2014/08/05 08:21:29 $
+#   $Revision: 1.8 $    $Date: 2014/10/24 00:22:30 $
 #
 #       dist2dpath    compute shortest path distances
 #
@@ -38,7 +38,6 @@ dist2dpath <- function(dist, method="C") {
            diag(adj) <- TRUE
            d <- dist
            d[!adj] <- -1
-           DUP <- spatstat.options("dupC")
            z <- .C("Ddist2dpath",
                    nv=as.integer(n),
                    d=as.double(d),
@@ -46,8 +45,7 @@ dist2dpath <- function(dist, method="C") {
                    dpath=as.double(numeric(n*n)),
                    tol=as.double(tol),
                    niter=as.integer(integer(1)),
-                   status=as.integer(integer(1)),
-                   DUP=DUP)
+                   status=as.integer(integer(1)))
            if(z$status == -1)
              warning(paste("C algorithm did not converge to tolerance", tol,
                            "after", z$niter, "iterations",
