@@ -3,7 +3,7 @@
 #
 #     Spatstat options and other internal states
 #
-#    $Revision: 1.59 $   $Date: 2014/11/12 10:24:25 $
+#    $Revision: 1.61 $   $Date: 2015/02/18 00:49:30 $
 #
 #
 
@@ -300,6 +300,12 @@ warn.once <- function(key, ...) {
          check=is.list,
          valid="a list"
          ),
+       par.pp3=list(
+         ## default graphics parameters for 'plot.pp3'
+         default=list(),
+         check=is.list,
+         valid="a list"
+         ),
        print.ppm.SE=list(
          ## under what conditions to print estimated SE in print.ppm
          default="poisson",
@@ -389,6 +395,14 @@ warn.once <- function(key, ...) {
          check=function(x) { length(x) == 1 && (x %in% 0:4) },
          valid="an integer between 0 and 4"
        ),
+       units.paren=list(
+         default="(",
+         check=function(x) {
+           is.character(x) && (length(x) == 1) &&
+             (x %in% c("(", "[", "{", ""))
+         },
+         valid="one of the strings '(', '[', '{' or '' "
+       ),
        use.Krect=list(
          ## whether to use function Krect in Kest(X) when window is rectangle
          default=TRUE,
