@@ -3,7 +3,7 @@
 #
 #  Smooth the marks of a point pattern
 # 
-#  $Revision: 1.22 $  $Date: 2014/10/24 00:22:30 $
+#  $Revision: 1.24 $  $Date: 2015/05/09 11:52:15 $
 #
 
 smooth.ppp <- function(X, ..., weights=rep(1, npoints(X)), at="pixels") {
@@ -16,6 +16,10 @@ Smooth <- function(X, ...) {
   UseMethod("Smooth")
 }
 
+Smooth.solist <- function(X, ...) {
+  solapply(X, Smooth, ...)
+}
+
 Smooth.ppp <- function(X, sigma=NULL, ...,
                        weights=rep(1, npoints(X)), at="pixels",
                        edge=TRUE, diggle=FALSE) {
@@ -202,7 +206,7 @@ Smooth.ppp <- function(X, sigma=NULL, ...,
                  }
                  attr(ratio, "warnings") <- uhoh
                }
-               result <- as.listof(ratio)
+               result <- as.solist(ratio)
                names(result) <- colnames(marx)
              })
     } else result <- NULL 
@@ -226,7 +230,7 @@ Smooth.ppp <- function(X, sigma=NULL, ...,
                  M <- do.call.matched(as.mask, list(w=as.owin(X), ...))
                }
                result[isconst] <- lapply(ra[1, isconst], as.im, W=M)
-               result <- as.listof(result)
+               result <- as.solist(result)
                names(result) <- colnames(oldmarx)
              })
     }
